CUE Codegen loading and evaluation
This module handles loading CUE codegen configurations and evaluating them to extract file definitions. A Codegen configuration is a CUE-based template that defines multiple files to generate for a project.
Structs
- Codegen
- CUE Codegen loader and evaluator
- Codegen
Data - CUE codegen data containing file definitions
- Format
Config - Format configuration for a code file
- Project
File Definition - A project file definition from the codegen configuration
Enums
- File
Mode - File generation mode